package org.broad.igv.event;

/**
 * Created by jrobinso on 6/24/17.
 */
public final class RefreshEvent implements IGVEvent {
}
